-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
-- At the start of the mission
function CigarShop:StartActivity()
   	print("START! -- CigarShop:StartActivity()!");
	
	self.braindead = {};

    self.GenericTimer = Timer();
    self.GenericTimer:Reset();


    	--------------------------
    	-- Set up teams

	-- There are currently 2 teams: TEAM_1 red and TEAM_2 green.
    	-- Team 2 is always CPU
    	self.CPUTeam = Activity.TEAM_2;
    
    	--------------------------
    self.ActivityState = Activity.EDITING;

    	-- Set up players
      -- From the first player to the last player (excludes CPU), do this.
      -- As of Build23, self.PlayerCount will only return 1.
    for player = 0, self.PlayerCount - 1 do


          -- Check if we already have a brain assigned
          -- GetPlayerBrain(player) returns false, because we haven't run SetPlayerBrain.
          -- We can't run SetPlayerBrain until we assign an actor (Commonly "Brain Case" or
          -- "Brain Robot") to be a vital brain.
          -- not false = true, so we continue on.
        if not self:GetPlayerBrain(player) then
			self.braindead[player] = false;

			local team = self:GetTeamOfPlayer(player);
			local newBrain = MovableMan:GetUnassignedBrain(team);
			-- If a suitable brain actor was found, make it a vital brain.
			if newBrain then
				self:SetPlayerBrain(newBrain, player);
				self:SwitchToActor(newBrain, player, team);
				if newBrain.PresetName == "Brain Robot" or newBrain.PresetName == "Heavy Brain Robot" then
					newBrain:AddInventoryItem(CreateHDFirearm("Auto Pistol","Coalition.rte"));
					newBrain:AddInventoryItem(CreateHDFirearm("Compact Assault Rifle","Coalition.rte"));
					newBrain.AIMode = Actor.AIMODE_SENTRY;
				end --if
			else
				  -- Lua will now associate the "Brain Robot" actor with
				  -- "brain.", but the actor isn't vital just yet.
				local brain = CreateAHuman("Brain Robot");
				  -- ???
				  -- Setting up where our Actor will appear
				brain.Pos = Vector(360,744-player*24);
				brain:AddInventoryItem(CreateHDFirearm("Auto Pistol","Coalition.rte"));
				brain:AddInventoryItem(CreateHDFirearm("Compact Assault Rifle","Coalition.rte"));
				brain.AIMode = Actor.AIMODE_SENTRY;
			              -- Place the 'Brain'-labeled Actor into the scene, according to brain.pos.
			            MovableMan:AddActor(brain);
			              -- Here our Brain Robot becomes a vital brain, because
			              -- GetPlayerBrain will now return true.
			            self:SetPlayerBrain(brain, player);
			              -- Set the found brain to be the selected actor at start
			            SceneMan:SetScroll(self:GetPlayerBrain(player).Pos, player);
			              -- ???
			            self:SetLandingZone(self:GetPlayerBrain(player).Pos, player);
			              -- Set the observation target to the player's brain, 
			              -- so that if/when it dies, the view flies to it in observation mode
			            self:SetObservationTarget(self:GetPlayerBrain(player).Pos, player);
			end -- if
        end	-- if
    end	-- for

    -- Set up AI modes for the Actors that have been added to the scene by the scene definition
    -- for all actors in the scene, do this.
    for actor in MovableMan.AddedActors do
         --  if the actor is on the cpu team
        if actor.Team == self.CPUTeam then
            actor.AIMode = Actor.AIMODE_SENTRY;
        end -- if
    end	-- for

    -- Set the team's funds to 3500 oz.
    self:SetTeamFunds(5000,Activity.TEAM_1);


    
end -- StartActivity function

-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------

function CigarShop:PauseActivity(pause)
    print("PAUSE! -- DummyAssault:PauseActivity()!");
end

-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------

function CigarShop:EndActivity()
    print("END! -- DummyAssault:EndActivity()!");
end

-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------

function CigarShop:UpdateActivity()
   	-- Clear all objective markers, they get re-added each frame
   	self:ClearObjectivePoints();

	if not (self.ActivityState == Activity.OVER) then
		-- Iterate through all human players
		for player = 0, self.PlayerCount - 1 do
			-- The current player's team
			local team = self:GetTeamOfPlayer(player);
	
			-- Make sure the game is not already ending: keep win/lose conditions in front.
			-- Check if any player's brain is dead
			local brain = self:GetPlayerBrain(player);
			-- If a vital brain died (GetPlayerBrain returned false)
			if not brain or not MovableMan:IsActor(brain) or not brain:HasObjectInGroup("Brains") then
				-- set the vital brain to nothing for the time being
				self:SetPlayerBrain(nil, player);
				-- Try to find a new unassigned brain this player can use instead, 
				--  or if his old brain entered a craft
				local newBrain = MovableMan:GetUnassignedBrain(team);
				-- If new brain actor found, make it a vital brain
				if newBrain and self.braindead[player] == false then
					self:SetPlayerBrain(newBrain, player);
					self:SwitchToActor(newBrain, player, team);
				else
					FrameMan:SetScreenText("Your brain has been lost!", player, 333, -1, false);
					self.braindead[player] = true;
					
					-- Now see if all brains of self player's team are dead, and if so, end the game
					if not MovableMan:GetClosestBrainActor(team) then
						self.WinnerTeam = self:OtherTeam(team);
						ActivityMan:EndActivity();
					end -- if
				end -- if
			else
				-- Update the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
				self:SetObservationTarget(brain.Pos, player)
			end -- if
		end --for

	-- Game over, show the appropriate messages until a certain time
	elseif not self.GameOverTimer:IsPastSimMS(self.GameOverPeriod) then
		for player = 0, self.PlayerCount - 1 do
			local team = self:GetTeamOfPlayer(player);
			if team == self.WinnerTeam then
				FrameMan:SetScreenText("You win!", player, 0, -1, false);
			else
				FrameMan:SetScreenText("Your brain has been lost!", player, 0, -1, false);
			end
		end
	end
	self:YSortObjectivePoints();
end -- UpdateActivity function